﻿using FichaBackend.Models;
using FichaBackend.Models.DTO;
using FichaBackend.Services;
using Microsoft.AspNetCore.Mvc;

namespace FichaBackend.Controllers;

[ApiController]
[Route("v1/")]
public class MainController : ControllerBase
{

    private readonly ILogger<MainController> _logger;
    private readonly IPublicDataService _publicDataService;

    public MainController(ILogger<MainController> logger, IPublicDataService publicDataService)
    {
        _logger = logger;
        _publicDataService = publicDataService;
    }
    
    [HttpGet("GetAllCity")]
    public async Task<IEnumerable<City>> GetAllCity()
    {
        return await _publicDataService.GetAllCity();
    }
    
    /// <summary>
    /// Получаем карточки с вопросами
    /// </summary>
    /// <returns></returns>
    [HttpGet("GetAllCards")]
    public async Task<IEnumerable<CardQuestion>> GetAllCards()
    {
        return await _publicDataService.GetAllCards();
    }
    
    /// <summary>
    /// Получаем все фильмы в городе по пушкинской карте
    /// </summary>
    /// <returns></returns>
    [HttpGet("GetAllFilmsInCity/{cityName}")]
    public async Task<ActionResult<IEnumerable<FilmDto>>> GetAllFilmsInCityWithPuskinCard(string cityName)
    {
        if (!_publicDataService.CityExsist(cityName))
            return BadRequest("City does not exsist");
        
        return Ok(await _publicDataService.GetAllFilmsInCity(cityName));
    }
    
    /// <summary>
    /// Получаем всех гидов, которые работают в определённом городе
    /// </summary>
    /// <returns></returns>
    [HttpGet("GetAllGuides/{cityName}")]
    public async Task<ActionResult> GetAllGuides(string cityName)
    {
        if(!_publicDataService.CityExsist(cityName))
            return BadRequest("City does not exsist");
        
        return Ok(await _publicDataService.GetAllGuides(cityName));
    }
    
    /// <summary>
    /// Получаем все музеи из одного города
    /// </summary>
    /// <returns></returns>
    [HttpGet("GetAllMuseum/{cityName}")]
    public async Task<ActionResult> GetAllMuseumFromCity(string cityName)
    {
        if(!_publicDataService.CityExsist(cityName))
            return BadRequest("City does not exsist");
        
        return Ok(await _publicDataService.GetAllMuseum(cityName));
    }
    
}